<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Vali terminali font</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Suurus:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Eelvaade</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>Bookmarks</source>
        <translation>Järjehoidjad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Keep window open when it loses focus</source>
        <translation>Jäta rakenduse aken avatuks ka siis, kui fookus on mujal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Terminali nägemiseks vajuta „%1“.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Kustuta aktiivne terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Järgmine kaart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Eelmine kaart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab in History</source>
        <translation>Eelmine aken ajaoos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Next Tab in History</source>
        <translation>Järgmine aken ajaloos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Move Tab &amp;Left</source>
        <translation>Liiguta kaart &amp;vasakule</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Right</source>
        <translation>Liiguta kaart &amp;paremale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Tab</source>
        <translation>Aken</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Go to</source>
        <translation>Mine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Jaga terminal &amp;horisontaalselt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Jaga terminal &amp;vertikaalselt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Keri allterminal kokku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Ülemine allterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Alumine allterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>L&amp;eft Subterminal</source>
        <translation>V&amp;asak allterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>R&amp;ight Subterminal</source>
        <translation>P&amp;arem allterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copy &amp;Selection</source>
        <translation>Kopeeri &amp;valik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Paste Clip&amp;board</source>
        <translation>Aseta lõike&amp;laud</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste S&amp;election</source>
        <translation>Aseta v&amp;alik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Zoom &amp;in</source>
        <translation>Suumi &amp;sisse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;out</source>
        <translation>Suumi &amp;välja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom rese&amp;t</source>
        <translation>Lähtesta &amp;suum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>&amp;Find...</source>
        <translation>&amp;Otsi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Handle history...</source>
        <translation>Töötle ajalugu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Salvesta seanss</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Laadi seanss</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>&amp;Toggle Menu</source>
        <translation>Näita või peida &amp;menüü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Rename session</source>
        <translation>Nimeta seanss ümber</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Uus kaart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Uus kaart &amp;eelseadistusest</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;horisontaalset terminali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;vertikaalset terminali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 terminal&amp;i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Sulge kaart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;New Window</source>
        <translation>&amp;Uus aken</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Eelistused...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>&amp;Quit</source>
        <translation>&amp;Välju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Peida akna piirid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Kuva kaardiriba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Fullscreen</source>
        <translation>Täisekraanivaade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Toggle Bookmarks</source>
        <translation>Lülita järjehoidjad sisse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>&amp;Bottom</source>
        <translation>&amp;All</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Top</source>
        <translation>&amp;Ülal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>&amp;Right</source>
        <translation>&amp;Paremal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;Left</source>
        <translation>&amp;Vasakul</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Kaartide paigutus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>&amp;None</source>
        <translation>&amp;Pole</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>S&amp;crollbar Layout</source>
        <translation>K&amp;erimisriba paigutus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Plokk-kursor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Allajoonitud kursor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;I-tala kursor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Klaviatuuri kursori kuju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Exit QTerminal</source>
        <translation>Lõpeta Qterminali töö</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Do not ask again</source>
        <translation>Ära küsi uuesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Are you sure you want to exit?</source>
        <translation>Soovid sa tõesti väljuda?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>About</source>
        <translation>Rakenduse teave</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Tõhus terminaliemulaator, mis toimib paljudel platvormidel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Copyright (C) </source>
        <translation>Autoriõigused (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>LXQt Project</source>
        <translation>LXQt projekt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Development: </source>
        <translation>Arendus: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="813"/>
        <source>Emulation</source>
        <translation>Emuleering</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Kiirklahvid</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Terminali seaded</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Välimus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Käitumine</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Lahtikeriv</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Järjehoidjad</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Peida kaardiriba ainult ühe kaardi puhul</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Värviskeem</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Kerimisriba asukoht</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Alusta eelseadistusega:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Kuva piir praeguse terminali ümber</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Terminali läbipaistvus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Rakenduse läbipaistvus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Puudub (üks terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminali horisontaalselt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 terminali vertikaalselt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 terminali</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Muuda...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Kaartide asukoht</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Vidina stiil</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Kuva menüüriba</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Muuda akna tiitlit aktiivse terminali järgi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Muuda akna ikooni aktiivse terminali järgi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Luba kahesuunaline tekstitugi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Taustapilt:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Vali</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Kuva terminali suuruse muutmine</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Näita igal kaardil sulgemisnuppu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Tühi ruum terminali sisu ja akna vahel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Kasuta fondifailis leiduvaid joonistamismärke</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Muuteklahvid käivitab vajutus Alt klahvile ning see võib segada terminali tööd.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Menüüriba muuteklahv puudub</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Tegevus pärast asetamist</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Confirm multiline paste</source>
        <translation>Kinnita mitmerealine asetamine</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="651"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Eemalda asetatava teksti lõpust tühjad read</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="747"/>
        <source>Open new terminals in current working directory</source>
        <translation>Ava uued terminalid praeguses töökataloogis</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="682"/>
        <source>Save Size when closing</source>
        <translation>Salvesta suurus sulgemisel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Save Position when closing</source>
        <translation>Salvesta asukoht sulgemisel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Ask for confirmation when closing</source>
        <translation>Küsi kinnitust sulgemisel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Piiramatu ajalugu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Ajaloo suurus (ridades)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Default $TERM</source>
        <translation>Vaikimisi $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="694"/>
        <source>Start with this size:</source>
        <translation>Alusta sellise mõõduga:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Taustarežiim:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Puudub</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Venita</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Suumi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Mahuta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Keskele</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Määratle, kas kastgraafika jaoks vajalikke märke QTerminal joonistab ise või kasutab väliseid kirjatüüpide visualiseerimise teeke.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Võtab intensiivsete värvide kuvamisel kasutusele paksu kirjatüübi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Kasuta intensiivsete värvide jaoks fondinägu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Peida akna piirjooned</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="822"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Missugust käitumist peaksime emuleerima ning see ei pea kattuma mujal operatsioonisüsteemis kasutatavaga.&lt;/p&gt;&lt;p&gt;Kui sa pole kindel, siis kasuta &lt;span style=&quot; font-weight:600;&quot;&gt;vaikimisi&lt;/span&gt; emulatsiooni.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="800"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Seda käsku käivitatakse argumendiga, milles leidub ajalugu sisaldava ajutise faili nimi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="803"/>
        <source>Handle history command</source>
        <translation>Käsk ajaloo töötlemiseks</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="701"/>
        <location filename="../forms/propertiesdialog.ui" line="715"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="722"/>
        <source>Get current size</source>
        <translation>Laadi praegune suurus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Ava uus kaart kasutusel oleva kaardi kõrval</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="754"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Kui see seadistus pole valitud, siis uus kaart avatakse paremas ääres</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="658"/>
        <source>Close tab on middle-click</source>
        <translation>Keskmise nupu klõps sulgeb kaardi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Üheselt blokeeri sulgudega asetamisrežiim</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Sulgudega asetamisrežiim on tuleb kasuks mitmerealise teksti asetamisel.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>Audible bell</source>
        <translation>Kuuldav kellahelin</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="846"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Kiirklahvi muutmiseks:
1. Topeltklõpsi tema võtmel
2. Vajuta soovitud klahvikombinatsiooni ning vabasta klahvid
3. Klõpsi kiirklahvil või vajuta Enter

Kiirklahvi kustutamiseks või väljalülitamiseks vajuta sammus 2 vaid muuteklahvi (nt Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="900"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Lukustuse nupp on kuvatud horisontaalsel kaardiribal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="903"/>
        <source>Keep window open when it loses focus</source>
        <translation>Jäta rakenduse aken avatuks ka siis, kui fookus on mujal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="921"/>
        <source>Height</source>
        <translation>Kõrgus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Width</source>
        <translation>Laius</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1029"/>
        <source>Edit bookmark file contents</source>
        <translation>Muuda järjehoidjate faili sisu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Enable bookmarks</source>
        <translation>Luba järjehoidjad</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="997"/>
        <source>Bookmark file</source>
        <translation>Järjehoidjate fail</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Show on start</source>
        <translation>Kuva käivitamisel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Kursori kuju</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Fikseeritud tabulaatorisamm:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Size</source>
        <translation>Suurus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="962"/>
        <source>Shortcut:</source>
        <translation>Kiirklahv:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1010"/>
        <source>Find...</source>
        <translation>Leia...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Võid määrata oma järjehoidjate faili asukoha. See võimaldab lihtsalt jagada järjehoidjaid vahenditega nagu OwnCloud või Dropbox.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="876"/>
        <source>Shortcut</source>
        <translation>Kiirklahv</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="881"/>
        <source>Key</source>
        <translation>Klahv</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Kerimisribata</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Vasakul</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Paremal</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Ülal</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>All</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Plokk kursor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Allajoonitud kursor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>I-tala kursor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Ära muuda asukohta</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Üles kerimine</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Alla kerimine</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="268"/>
        <source>Examples</source>
        <translation>Näited</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Pildid (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="511"/>
        <source>Open bookmarks file</source>
        <translation>Ava järjehoidjate fail</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="513"/>
        <source>XML files (*.xml)</source>
        <translation>XML failid (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>All files (*)</source>
        <translation>Kõik failid (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>Question</source>
        <translation>Küsimus</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Kas sa soovid asendada olemasoleva järjehoidjate faili?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Järjehoidjate failil puudub xml-laiend.
Kas sa oled kindel, et see on õige fail ja soovid seda asendada?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Warning</source>
        <translation>Hoiatus</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Järjehoidjaid ei õnnestu salvestada sellesse faili:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="203"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Süsteemne vaikeväärtus</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="420"/>
        <source>Choose a background image</source>
        <translation>Vali taustapilt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Sünkroonitud järjehoidjad</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="80"/>
        <location filename="../tabwidget.cpp" line="234"/>
        <source>Shell No. %1</source>
        <translation>Kest nr. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="202"/>
        <source>Tab name</source>
        <translation>Kaardi nimi</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>New tab name:</source>
        <translation>Kaardi uus nimi:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>Select new tab title color</source>
        <translation>Vali uus kaardi pealkirja värv</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="252"/>
        <source>Close session</source>
        <translation>Sulge seanss</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Change title color</source>
        <translation>Muuda pealkirja värvi</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Lae seanss</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Salvestatud seansside nimekiri:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Peaaken</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Tegevused</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Abiteave</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Vaade</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muuda</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Teave...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>&amp;Qt info...</translation>
    </message>
</context>
</TS>
